@@ -22,10 +22,16 @@ sub get_image_info($);
 # This allows declaration	use Image::EXIF ':all';
 # If you do not need this, moving things directly into @EXPORT or @EXPORT_OK
 # will save memory.
-our %EXPORT_TAGS = ( 'all' => [ qw() ] );
+our %EXPORT_TAGS = ( 'all' => [ qw(
+	
+) ] );
+
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
-our @EXPORT = qw();
-our $VERSION = '0.99.4';
+
+our @EXPORT = qw(
+	
+);
+our $VERSION = '0.04';
 
 sub AUTOLOAD {
     # This AUTOLOAD is used to 'autoload' constants from the constant()
@@ -167,7 +173,7 @@ sub get_other_info($)
 	$hash;
 }
 
-sub get_unknown_info($)
+sub get_unknow_info($)
 {
 	my $self = shift;
 
@@ -176,7 +182,7 @@ sub get_unknown_info($)
 	if (c_errstr()){
 		push @{$self->{errstr}}, c_errstr();
 	} else {
-		c_get_unknown_info();
+		c_get_unknow_info();
 		while(my ($fld, $val) = c_fetch()){
 			$fld eq '' && next;
 			$val =~ s/\s*$//g;
@@ -217,11 +223,11 @@ sub get_all_info($)
 	                $hash->{other}->{$fld} = $val;
         	}
 
-		c_get_unknown_info();
+		c_get_unknow_info();
 		while(my ($fld, $val) = c_fetch()){
 			$fld eq '' && next;
 			$val =~ s/\s*$//g;
-	                $hash->{unknown}->{$fld} = $val;
+	                $hash->{unknow}->{$fld} = $val;
         	}
 	}
 
@@ -257,15 +263,15 @@ Image::EXIF - Perl extension for exif library
    my $camera_info = $exif->get_camera_info(); # hash reference
    my $other_info = $exif->get_other_info(); # hash reference
    my $point_shoot_info = $exif->get_point_shoot_info(); # hash reference
-   my $unknown_info = $exif->get_unknown_info(); # hash reference
+   my $unknow_info = $exif->get_unknow_info(); # hash reference
    my $all_info = $exif->get_all_info(); # hash reference
 
    print $exif->error ?
-	$exif->errstr : Dumper($all_info);
+	$exit->errstr : Dumper($all_info);
 
 =head1 DESCRIPTION
 
-Perl Package Image::EXIF based on utility exiftags v0.99.1
+Perl Package Image::EXIF based on utility exiftags v0.97
 by Eric M. Johnston, emj@postal.net, http://johnst.org/sw/exiftags/.
 Actually it's just a wrapper. Weak PHP's support of EXIF
 made me write it.
